@@ -1101,16 +1101,6 @@ Having defined the above callbacks, customized to your app/data store/etc, you
 can configuration the module:
 
   my $Grant = Net::OAuth2::AuthorizationServer::AuthorizationCodeGrant->new(
-    clients => {
-      TrendyNewService => {
-        client_secret => 'TopSecretClientSecret',
-        scopes        => {
-          post_images   => 1,
-          annoy_friends => 1,
-        },
-      },
-      ...
-    }
     login_resource_owner_cb      => $resource_owner_logged_in_sub,
     confirm_by_resource_owner_cb => $resource_owner_confirm_scopes_sub,
     verify_client_cb             => $verify_client_sub,
@@ -1120,6 +1110,9 @@ can configuration the module:
     verify_access_token_cb       => $verify_access_token_sub,
   );
 
+Note because we are using the verify_client_cb above we do not need to pass
+a hashref of clients - this will be handled in the verify_client_cb sub
+
 =head1 EXAMPLES
 
 There are more examples included with this distribution in the examples/ dir.
